==> jc-1.4.0.tar.gz: soot/jimple/spark/solver/PropWorklist.h <==
// public final class soot.jimple.spark.solver.PropWorklist

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ab3c55d533a78fcc soot_jimple_spark_solver_PropWorklist
// @dep_class ba679de9a7cc1f7a soot_jimple_spark_solver_Propagator

// header file dependencies
// @dep_header soot_jimple_spark_solver_Propagator

#include "soot/jimple/spark/solver/Propagator.h"

#ifndef _JC_soot_jimple_spark_solver_PropWorklist_H_
#define _JC_soot_jimple_spark_solver_PropWorklist_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashSet$object;
struct _jc_java_util_Set$object;
struct _jc_soot_jimple_spark_pag_AllocNode$object;
struct _jc_soot_jimple_spark_pag_FieldRefNode$object;
struct _jc_soot_jimple_spark_pag_PAG$object;
struct _jc_soot_jimple_spark_pag_VarNode$object;
struct _jc_soot_jimple_spark_solver_OnFlyCallGraph$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_solver_PropWorklist$sub_refs	_jc_soot_jimple_spark_solver_PropWorklist$sub_refs;
typedef struct _jc_soot_jimple_spark_solver_PropWorklist$sub_nonrefs	_jc_soot_jimple_spark_solver_PropWorklist$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropWorklist$refs	_jc_soot_jimple_spark_solver_PropWorklist$refs;
typedef struct _jc_soot_jimple_spark_solver_PropWorklist$nonrefs	_jc_soot_jimple_spark_solver_PropWorklist$nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropWorklist$object	_jc_soot_jimple_spark_solver_PropWorklist$object;

typedef const struct _jc_soot_jimple_spark_solver_PropWorklist$vmethods	_jc_soot_jimple_spark_solver_PropWorklist$vmethods;
typedef const struct _jc_soot_jimple_spark_solver_PropWorklist$vtable	_jc_soot_jimple_spark_solver_PropWorklist$vtable;
typedef const struct _jc_soot_jimple_spark_solver_PropWorklist$vtype	_jc_soot_jimple_spark_solver_PropWorklist$vtype;

// Constructors
extern void _jc_soot_jimple_spark_solver_PropWorklist$method$_init$d432acd4fd080ea1(_jc_env *, struct _jc_soot_jimple_spark_solver_PropWorklist$object *, struct _jc_soot_jimple_spark_pag_PAG$object *);

// Virtual methods
extern jboolean _jc_soot_jimple_spark_solver_PropWorklist$method$handleAllocNode$873c6896d414424f(_jc_env *, struct _jc_soot_jimple_spark_solver_PropWorklist$object *, struct _jc_soot_jimple_spark_pag_AllocNode$object *);
extern void _jc_soot_jimple_spark_solver_PropWorklist$method$handleFieldRefNode$6233344af340f0ef(_jc_env *, struct _jc_soot_jimple_spark_solver_PropWorklist$object *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *, struct _jc_java_util_HashSet$object *);
extern jboolean _jc_soot_jimple_spark_solver_PropWorklist$method$handleVarNode$38f043a08670ae06(_jc_env *, struct _jc_soot_jimple_spark_solver_PropWorklist$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *);
extern void _jc_soot_jimple_spark_solver_PropWorklist$method$propagate$430f3309bbb43666(_jc_env *, struct _jc_soot_jimple_spark_solver_PropWorklist$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_solver_PropWorklist$method_info$handleAllocNode$873c6896d414424f;
extern _jc_method _jc_soot_jimple_spark_solver_PropWorklist$method_info$handleFieldRefNode$6233344af340f0ef;
extern _jc_method _jc_soot_jimple_spark_solver_PropWorklist$method_info$handleVarNode$38f043a08670ae06;
extern _jc_method _jc_soot_jimple_spark_solver_PropWorklist$method_info$propagate$430f3309bbb43666;

// Virtual methods structure
struct _jc_soot_jimple_spark_solver_PropWorklist$vmethods {
	jboolean	(*handleAllocNode$873c6896d414424f)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropWorklist$object *, struct _jc_soot_jimple_spark_pag_AllocNode$object *);
	void	(*handleFieldRefNode$6233344af340f0ef)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropWorklist$object *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *, struct _jc_java_util_HashSet$object *);
	jboolean	(*handleVarNode$38f043a08670ae06)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropWorklist$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *);
	void	(*propagate$430f3309bbb43666)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropWorklist$object *);
};

// Vtable
struct _jc_soot_jimple_spark_solver_PropWorklist$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_solver_Propagator$vmethods	soot_jimple_spark_solver_Propagator;
	_jc_soot_jimple_spark_solver_PropWorklist$vmethods	soot_jimple_spark_solver_PropWorklist;
};

// Vtype
struct _jc_soot_jimple_spark_solver_PropWorklist$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_solver_PropWorklist$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropWorklist$sub_refs {
	struct _jc_object	*varNodeWorkList;
	struct _jc_soot_jimple_spark_pag_PAG$object	*pag;
	struct _jc_soot_jimple_spark_solver_OnFlyCallGraph$object	*ofcg;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropWorklist$refs {
    _jc_soot_jimple_spark_solver_PropWorklist$sub_refs	soot_jimple_spark_solver_PropWorklist;
    _jc_soot_jimple_spark_solver_Propagator$sub_refs	soot_jimple_spark_solver_Propagator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropWorklist$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropWorklist$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_solver_Propagator$sub_nonrefs	soot_jimple_spark_solver_Propagator;
    _jc_soot_jimple_spark_solver_PropWorklist$sub_nonrefs	soot_jimple_spark_solver_PropWorklist;
};

// Object instance structure
struct _jc_soot_jimple_spark_solver_PropWorklist$object {
	_jc_soot_jimple_spark_solver_PropWorklist$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_solver_PropWorklist$vtype	*vtype;
	_jc_soot_jimple_spark_solver_PropWorklist$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_solver_PropWorklist$vtype _jc_soot_jimple_spark_solver_PropWorklist$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_solver_PropWorklist, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_solver_PropWorklist$class_object;

#endif	/* _JC_soot_jimple_spark_solver_PropWorklist_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/solver/PropWorklist.h <==
// public final class soot.jimple.spark.solver.PropWorklist

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ab3c55d533a78fcc soot_jimple_spark_solver_PropWorklist
// @dep_class ba679de9a7cc1f7a soot_jimple_spark_solver_Propagator

// header file dependencies
// @dep_header soot_jimple_spark_solver_Propagator

#include "soot/jimple/spark/solver/Propagator.h"

#ifndef _JC_soot_jimple_spark_solver_PropWorklist_H_
#define _JC_soot_jimple_spark_solver_PropWorklist_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashSet$object;
struct _jc_java_util_Set$object;
struct _jc_soot_jimple_spark_pag_AllocNode$object;
struct _jc_soot_jimple_spark_pag_FieldRefNode$object;
struct _jc_soot_jimple_spark_pag_PAG$object;
struct _jc_soot_jimple_spark_pag_VarNode$object;
struct _jc_soot_jimple_spark_solver_OnFlyCallGraph$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_solver_PropWorklist$sub_refs	_jc_soot_jimple_spark_solver_PropWorklist$sub_refs;
typedef struct _jc_soot_jimple_spark_solver_PropWorklist$sub_nonrefs	_jc_soot_jimple_spark_solver_PropWorklist$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropWorklist$refs	_jc_soot_jimple_spark_solver_PropWorklist$refs;
typedef struct _jc_soot_jimple_spark_solver_PropWorklist$nonrefs	_jc_soot_jimple_spark_solver_PropWorklist$nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropWorklist$object	_jc_soot_jimple_spark_solver_PropWorklist$object;

typedef const struct _jc_soot_jimple_spark_solver_PropWorklist$vmethods	_jc_soot_jimple_spark_solver_PropWorklist$vmethods;
typedef const struct _jc_soot_jimple_spark_solver_PropWorklist$vtable	_jc_soot_jimple_spark_solver_PropWorklist$vtable;
typedef const struct _jc_soot_jimple_spark_solver_PropWorklist$vtype	_jc_soot_jimple_spark_solver_PropWorklist$vtype;

// Constructors
extern void _jc_soot_jimple_spark_solver_PropWorklist$method$_init$d432acd4fd080ea1(_jc_env *, struct _jc_soot_jimple_spark_solver_PropWorklist$object *, struct _jc_soot_jimple_spark_pag_PAG$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_spark_solver_PropWorklist$method$handleAllocNode$873c6896d414424f(_jc_env *, struct _jc_soot_jimple_spark_solver_PropWorklist$object *, struct _jc_soot_jimple_spark_pag_AllocNode$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_solver_PropWorklist$method$handleFieldRefNode$6233344af340f0ef(_jc_env *, struct _jc_soot_jimple_spark_solver_PropWorklist$object *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *, struct _jc_java_util_HashSet$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_spark_solver_PropWorklist$method$handleVarNode$38f043a08670ae06(_jc_env *, struct _jc_soot_jimple_spark_solver_PropWorklist$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_solver_PropWorklist$method$propagate$430f3309bbb43666(_jc_env *, struct _jc_soot_jimple_spark_solver_PropWorklist$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_solver_PropWorklist$method_info$handleAllocNode$873c6896d414424f;
extern _jc_method _jc_soot_jimple_spark_solver_PropWorklist$method_info$handleFieldRefNode$6233344af340f0ef;
extern _jc_method _jc_soot_jimple_spark_solver_PropWorklist$method_info$handleVarNode$38f043a08670ae06;
extern _jc_method _jc_soot_jimple_spark_solver_PropWorklist$method_info$propagate$430f3309bbb43666;

// Virtual methods structure
struct _jc_soot_jimple_spark_solver_PropWorklist$vmethods {
	jboolean	(*handleAllocNode$873c6896d414424f)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropWorklist$object *, struct _jc_soot_jimple_spark_pag_AllocNode$object *) _JC_JCNI_ATTR;
	void	(*handleFieldRefNode$6233344af340f0ef)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropWorklist$object *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *, struct _jc_java_util_HashSet$object *) _JC_JCNI_ATTR;
	jboolean	(*handleVarNode$38f043a08670ae06)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropWorklist$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *) _JC_JCNI_ATTR;
	void	(*propagate$430f3309bbb43666)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropWorklist$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_solver_PropWorklist$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_solver_Propagator$vmethods	soot_jimple_spark_solver_Propagator;
	_jc_soot_jimple_spark_solver_PropWorklist$vmethods	soot_jimple_spark_solver_PropWorklist;
};

// Vtype
struct _jc_soot_jimple_spark_solver_PropWorklist$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_solver_PropWorklist$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropWorklist$sub_refs {
	struct _jc_object	*varNodeWorkList;
	struct _jc_soot_jimple_spark_pag_PAG$object	*pag;
	struct _jc_soot_jimple_spark_solver_OnFlyCallGraph$object	*ofcg;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropWorklist$refs {
    _jc_soot_jimple_spark_solver_PropWorklist$sub_refs	soot_jimple_spark_solver_PropWorklist;
    _jc_soot_jimple_spark_solver_Propagator$sub_refs	soot_jimple_spark_solver_Propagator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropWorklist$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropWorklist$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_solver_Propagator$sub_nonrefs	soot_jimple_spark_solver_Propagator;
    _jc_soot_jimple_spark_solver_PropWorklist$sub_nonrefs	soot_jimple_spark_solver_PropWorklist;
};

// Object instance structure
struct _jc_soot_jimple_spark_solver_PropWorklist$object {
	_jc_soot_jimple_spark_solver_PropWorklist$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_solver_PropWorklist$vtype	*vtype;
	_jc_soot_jimple_spark_solver_PropWorklist$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_solver_PropWorklist$vtype _jc_soot_jimple_spark_solver_PropWorklist$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_solver_PropWorklist, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_solver_PropWorklist$class_object;

#endif	/* _JC_soot_jimple_spark_solver_PropWorklist_H_ */
